# coding: utf-8

"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TangConnectivityResponseTangServerResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'tang_url': 'str',
        'payload': 'str',
        'signatures': 'list[TangConnectivityResponseSignatures]'
    }

    attribute_map = {
        'tang_url': 'tang_url',
        'payload': 'payload',
        'signatures': 'signatures'
    }

    def __init__(self, tang_url=None, payload=None, signatures=None):  # noqa: E501
        """TangConnectivityResponseTangServerResponse - a model defined in Swagger"""  # noqa: E501

        self._tang_url = None
        self._payload = None
        self._signatures = None
        self.discriminator = None

        if tang_url is not None:
            self.tang_url = tang_url
        if payload is not None:
            self.payload = payload
        if signatures is not None:
            self.signatures = signatures

    @property
    def tang_url(self):
        """Gets the tang_url of this TangConnectivityResponseTangServerResponse.  # noqa: E501

        Tang URL.  # noqa: E501

        :return: The tang_url of this TangConnectivityResponseTangServerResponse.  # noqa: E501
        :rtype: str
        """
        return self._tang_url

    @tang_url.setter
    def tang_url(self, tang_url):
        """Sets the tang_url of this TangConnectivityResponseTangServerResponse.

        Tang URL.  # noqa: E501

        :param tang_url: The tang_url of this TangConnectivityResponseTangServerResponse.  # noqa: E501
        :type: str
        """

        self._tang_url = tang_url

    @property
    def payload(self):
        """Gets the payload of this TangConnectivityResponseTangServerResponse.  # noqa: E501

        Tang response payload.  # noqa: E501

        :return: The payload of this TangConnectivityResponseTangServerResponse.  # noqa: E501
        :rtype: str
        """
        return self._payload

    @payload.setter
    def payload(self, payload):
        """Sets the payload of this TangConnectivityResponseTangServerResponse.

        Tang response payload.  # noqa: E501

        :param payload: The payload of this TangConnectivityResponseTangServerResponse.  # noqa: E501
        :type: str
        """

        self._payload = payload

    @property
    def signatures(self):
        """Gets the signatures of this TangConnectivityResponseTangServerResponse.  # noqa: E501


        :return: The signatures of this TangConnectivityResponseTangServerResponse.  # noqa: E501
        :rtype: list[TangConnectivityResponseSignatures]
        """
        return self._signatures

    @signatures.setter
    def signatures(self, signatures):
        """Sets the signatures of this TangConnectivityResponseTangServerResponse.


        :param signatures: The signatures of this TangConnectivityResponseTangServerResponse.  # noqa: E501
        :type: list[TangConnectivityResponseSignatures]
        """

        self._signatures = signatures

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TangConnectivityResponseTangServerResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TangConnectivityResponseTangServerResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
